@@ -995,6 +995,11 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *c, MSObj *obj)
 		 */
 		guint16 len = GSF_LE_GET_GUINT16(data+2);
 
+		// The would-be "len" field has different meaning for
+		// GR_LISTBOX_DATA.
+		if (record_type != GR_LISTBOX_DATA)
+			XL_CHECK_CONDITION_VAL (data_len_left >= 4 + len, TRUE);
+
 		/* 1st record must be COMMON_OBJ*/
 		XL_CHECK_CONDITION_VAL (obj->excel_type >= 0 ||
 				      record_type == GR_COMMON_OBJ_DATA,
@@ -1060,6 +1065,7 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *c, MSObj *obj)
 			break;
 
 		case GR_SCROLLBAR :
+			XL_CHECK_CONDITION_VAL (data_len_left >= 20, TRUE);
 			ms_obj_attr_bag_insert (obj->attrs,
 				ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_VALUE,
 					GSF_LE_GET_GUINT16 (data+8)));
@@ -1131,7 +1137,11 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *c, MSObj *obj)
 			break;
 
 		case GR_COMMON_OBJ_DATA : {
-			guint16 const options = GSF_LE_GET_GUINT16 (data+8);
+			guint16 options;
+
+			XL_CHECK_CONDITION_VAL (data_len_left >= 10, TRUE);
+
+			options = GSF_LE_GET_GUINT16 (data+8);
 
 			/* Multiple objects in 1 record ?? */
 			XL_CHECK_CONDITION_VAL (obj->excel_type == -1, TRUE);
