@@ -177,17 +177,17 @@ xls_read_pivot_cache_values (XLSReadPivot *s, BiffQuery *q, unsigned int n, cons
 {
 	/* TODO : go_val_array_sized_new */
 	GPtrArray *res = g_ptr_array_sized_new (n);
-	GnmValue *v;
 	unsigned int i;
 
 	d (1, g_printerr ("/* %u %s items */ ;\n", n, type););
 	for (i = 0 ; i < n ; i++) {
-		if (NULL == (v = xls_read_pivot_cache_value (s, q))) {
-	/* TODO : go_val_array_set_size */
-			g_ptr_array_set_size (res, i);
+		GnmValue *v = xls_read_pivot_cache_value (s, q);
+		if (!v) {
+			/* TODO : go_val_array_set_size */
+			g_ptr_array_set_size (res, n);
 			return res;
 		}
-	/* TODO : go_val_array_add */
+		/* TODO : go_val_array_add */
 		g_ptr_array_add (res, v);
 	}
 	return res;
@@ -389,7 +389,7 @@ xls_read_pivot_cache (XLSReadPivot *s, BiffQuery *q)
 		/* guint16 zero */
 		guint16 type		= GSF_LE_GET_GUINT16 (q->data + 16);
 		g_printerr ("num_rec = %u;\nstream_id = %u;\n"
-			 "rec per block = %u;\nbase fields = %hu;\ntotal fields = %hu;\n"
+			 "rec per block = %u;\nbase fields = %hu;\ntotal fields = %u;\n"
 			 "last modified by = '%s';type = 0x%x, flags = 0x%x;\n",
 			 num_records, stream_id, rec_per_block, base_fields,
 			 num_fields, refreshedBy, type, flags);
@@ -417,7 +417,7 @@ xls_read_pivot_cache (XLSReadPivot *s, BiffQuery *q)
 			return FALSE;
 		}
 
-	go_data_cache_import_start (s->cache, num_records);
+	go_data_cache_import_start (s->cache, MIN (num_records, 10000u));
 	record_count = 0;
 	while (ms_biff_query_peek_next (q, &opcode) && opcode != BIFF_EOF) {
 		switch (opcode) {
@@ -748,6 +748,7 @@ xls_read_SXVIEW (BiffQuery *q, ExcelReadSheet *esheet)
 	name = go_string_new_nocopy (
 		excel_get_text (imp, q->data + 44, name_len,
 			       &len, NULL, q->length - 44));
+	len = MIN (len, q->length - 44);
 	data_field_name = go_string_new_nocopy (
 		excel_get_text (imp, q->data + 44 + len, data_field_name_len,
 				&len, NULL, q->length - 44 - len));
