@@ -90,7 +90,7 @@ xlsx_write_series_dim (XLSXWriteState *state, GsfXMLOut *xml, GogSeries const *s
 	int dim;
 	GOData const *dat;
 
-	for (dim = -1; dim < (int) desc->num_dim; dim++)
+	for (dim = 0; dim < (int) desc->num_dim; dim++)
 		if (desc->dim[dim].ms_type == ms_type)
 			break;
 	if (dim == (int) desc->num_dim)
@@ -320,7 +320,11 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style, const XLSXStyleContext
 	gboolean has_font_color = ((style->interesting_fields & GO_STYLE_FONT) &&
 				   !style->font.auto_color);
 	gboolean has_font = xlsx_go_style_has_font (style);
+	gboolean has_layout_angle = ((style->interesting_fields & GO_STYLE_TEXT_LAYOUT) &&
+				     !style->text_layout.auto_angle);
 	gboolean ext_fill_pattern = FALSE;
+	gboolean ext_fill_auto_pattern = FALSE;
+	gboolean ext_fill_auto_back = FALSE;
 	gboolean ext_start_arrow = FALSE;
 	gboolean ext_end_arrow = FALSE;
 	gboolean ext_gradient_rev = FALSE;
@@ -355,21 +359,19 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style, const XLSXStyleContext
 			/* FIXME: export image */
 		case GO_STYLE_FILL_NONE:
 			gsf_xml_out_simple_element (xml, "a:noFill", NULL);
-			break;			
+			break;
 		case GO_STYLE_FILL_PATTERN: {
 			const char *pattname = NULL;
+			ext_fill_auto_pattern = TRUE;
 			switch (style->fill.pattern.pattern) {
 			case GO_PATTERN_SOLID:
 				ext_fill_pattern = TRUE;
-				if (!style->fill.auto_back) {
+				if (!style->fill.auto_back || sctx->must_fill_fill) {
+					if (style->fill.auto_back)
+						ext_fill_auto_back = TRUE;
 					gsf_xml_out_start_element (xml, "a:solidFill");
 					xlsx_write_rgbarea (xml, style->fill.pattern.back);
 					gsf_xml_out_end_element (xml);
-				} else if (sctx->must_fill_fill) {
-					/* We must output a color, or we'll get the foreground colour, i.e., black. */
-					gsf_xml_out_start_element (xml, "a:solidFill");
-					xlsx_write_rgbarea (xml, GO_COLOR_WHITE);
-					gsf_xml_out_end_element (xml);
 				}
 				break;
 			case GO_PATTERN_FOREGROUND_SOLID:
@@ -557,7 +559,8 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style, const XLSXStyleContext
 	}
 
 	if (sctx->state->with_extension &&
-	    (ext_fill_pattern || ext_start_arrow || ext_end_arrow ||
+	    (ext_fill_pattern || ext_fill_auto_pattern || ext_fill_auto_back ||
+	     ext_start_arrow || ext_end_arrow ||
 	     ext_gradient_rev || ext_dash_type)) {
 		gsf_xml_out_start_element (xml, "a:extLst");
 		gsf_xml_out_start_element (xml, "a:ext");
@@ -570,7 +573,14 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style, const XLSXStyleContext
 					      : go_line_dash_as_str (style->line.dash_type));
 		}
 		if (ext_fill_pattern) {
-			gsf_xml_out_add_cstr (xml, "pattern", go_pattern_as_str (style->fill.pattern.pattern));
+			gsf_xml_out_add_cstr (xml, "pattern",
+					      go_pattern_as_str (style->fill.pattern.pattern));
+		}
+		if (ext_fill_auto_pattern) {
+			xlsx_add_bool (xml, "auto-pattern", style->fill.auto_type);
+		}
+		if (ext_fill_auto_back) {
+			xlsx_add_bool (xml, "auto-back", style->fill.auto_back);
 		}
 		if (ext_start_arrow) {
 			GOArrow const *arrow = sctx->start_arrow;
@@ -597,9 +607,18 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style, const XLSXStyleContext
 	gsf_xml_out_end_element (xml);  /* "NS:spPr" */
 	g_free (spPr_tag);
 
-	if (has_font_color || has_font) {
+	if (has_font_color || has_font || has_layout_angle) {
 		gsf_xml_out_start_element (xml, "c:txPr");
-		gsf_xml_out_simple_element (xml, "a:bodyPr", NULL);
+
+		gsf_xml_out_start_element (xml, "a:bodyPr");
+		if (has_layout_angle) {
+			double angle = fmod (360 - style->text_layout.angle, 360.0);
+			if (angle <= -180) angle += 360;
+			if (angle > 180) angle -= 360;
+			gsf_xml_out_add_int (xml, "rot", (int)(angle * 60000));
+		}
+		gsf_xml_out_end_element (xml);  /* "a:bodyPr" */
+
 		gsf_xml_out_simple_element (xml, "a:lstStyle", NULL);
 		gsf_xml_out_start_element (xml, "a:p");
 		gsf_xml_out_start_element (xml, "a:pPr");
@@ -775,7 +794,7 @@ xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogPlot *plot, GogAxis *
 	gsf_xml_out_end_element (xml);
 
 	{
-		gboolean mati, miti, mato, mito;
+		gboolean mati, miti, mato, mito, mal;
 		static const char *marks[4] = { "none", "in", "out", "cross" };
 
 		g_object_get (G_OBJECT (axis),
@@ -783,11 +802,14 @@ xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogPlot *plot, GogAxis *
 			      "minor-tick-in", &miti,
 			      "major-tick-out", &mato,
 			      "minor-tick-out", &mito,
+			      "major-tick-labeled", &mal,
 			      NULL);
 		xlsx_write_chart_cstr_unchecked (xml, "c:majorTickMark",
 						 marks[2 * mato + mati]);
 		xlsx_write_chart_cstr_unchecked (xml, "c:minorTickMark",
 						 marks[2 * mito + miti]);
+		if (!mal)
+			xlsx_write_chart_cstr_unchecked (xml, "c:tickLblPos", "none");
 	}
 
 	xlsx_write_go_style (xml, state, go_styled_object_get_style (GO_STYLED_OBJECT (axis)));
@@ -818,6 +840,15 @@ xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogPlot *plot, GogAxis *
 	d = gog_axis_get_entry (axis, GOG_AXIS_ELEM_MINOR_TICK, &user_defined);
 	if (user_defined && d > 0) xlsx_write_chart_float (xml, "c:minorUnit", d);
 
+	g_object_get (axis, "display-factor", &d, NULL);
+	if (d != 1.) {
+		gsf_xml_out_start_element (xml, "c:dispUnits");
+		gsf_xml_out_start_element (xml, "c:custUnit");
+		gsf_xml_out_add_float (xml, "val", d, -1);
+		gsf_xml_out_end_element (xml);
+		gsf_xml_out_end_element (xml);
+	}
+
 	/* finished with axis */
 	gsf_xml_out_end_element (xml);
 }
@@ -912,6 +943,8 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml,
 	case XLSX_PT_GOGRADARAREAPLOT:
 		gsf_xml_out_start_element (xml, "c:radarChart");
 		xlsx_write_chart_cstr_unchecked (xml, "c:radarStyle", "standard");
+		xlsx_write_chart_bool (xml, "c:varyColors", vary_by_element);
+		has_lines = TRUE;
 		axis_type[0] = GOG_AXIS_CIRCULAR;
 		axis_type[1] = GOG_AXIS_RADIAL;
 		break;
@@ -1138,8 +1171,10 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml,
 	for (i = 0; i < 3; i++) {
 		if (axis_type[i] != GOG_AXIS_UNKNOWN) {
 			GogAxis *axis = gog_plot_get_axis (GOG_PLOT (plot), axis_type[i]);
-			xlsx_write_chart_uint (xml, "c:axId", xlsx_get_axid (state, axis));
-			axes = g_slist_append (axes, axis);
+			if (axis) {
+				xlsx_write_chart_uint (xml, "c:axId", xlsx_get_axid (state, axis));
+				axes = g_slist_append (axes, axis);
+			}
 		}
 	}
 
@@ -1206,8 +1241,14 @@ xlsx_write_one_chart (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *ch
 	xlsx_write_plots (state, xml, chart, &ser_count);
 
 	obj = gog_object_get_child_by_name (GOG_OBJECT (chart), "Backplane");
-	if (obj)
-		xlsx_write_go_style (xml, state, go_styled_object_get_style (GO_STYLED_OBJECT (obj)));
+	if (obj) {
+		XLSXStyleContext sctx;
+		xlsx_style_context_init (&sctx, state);
+		sctx.must_fill_fill = TRUE;
+		xlsx_write_go_style_full
+			(xml, go_styled_object_get_style (GO_STYLED_OBJECT (obj)),
+			 &sctx);
+	}
 
 	gsf_xml_out_end_element (xml); /* </c:plotArea> */
 
