@@ -124,6 +124,7 @@ glpk_create_program (GnmSubSolver *ssol, GOIOContext *io_context, GError **err)
 	GnmSolverParameters *sp = sol->params;
 	GString *prg = NULL;
 	GString *constraints = g_string_new (NULL);
+	GString *bounds = g_string_new (NULL);
 	GString *binaries = g_string_new (NULL);
 	GString *integers = g_string_new (NULL);
 	GString *objfunc = g_string_new (NULL);
@@ -133,6 +134,7 @@ glpk_create_program (GnmSubSolver *ssol, GOIOContext *io_context, GError **err)
 	gsize progress;
 	GPtrArray *old = NULL;
 	gnm_float *x1 = NULL, *x2 = NULL;
+	int cidx = 0;
 
 	/* ---------------------------------------- */
 
@@ -160,7 +162,7 @@ glpk_create_program (GnmSubSolver *ssol, GOIOContext *io_context, GError **err)
 	/* ---------------------------------------- */
 
 	progress = 3;
-	if (sp->options.assume_non_negative) progress++;
+	/* assume_non_negative */ progress++;
 	if (sp->options.assume_discrete) progress++;
 	progress += g_slist_length (sp->constraints);
 
@@ -196,12 +198,15 @@ glpk_create_program (GnmSubSolver *ssol, GOIOContext *io_context, GError **err)
 
 	/* ---------------------------------------- */
 
-	if (sp->options.assume_non_negative) {
+	{
 		unsigned ui;
 		for (ui = 0; ui < input_cells->len; ui++) {
 			GnmCell *cell = g_ptr_array_index (input_cells, ui);
-			g_string_append_printf (constraints, " %s >= 0\n",
-						glpk_var_name (ssol, cell));
+			const char *name = glpk_var_name (ssol, cell);
+			if (sp->options.assume_non_negative)
+				g_string_append_printf (bounds, " %s >= 0\n", name);
+			else
+				g_string_append_printf (bounds, " %s free\n", name);
 		}
 		go_io_count_progress_update (io_context, 1);
 	}
@@ -248,16 +253,23 @@ glpk_create_program (GnmSubSolver *ssol, GOIOContext *io_context, GError **err)
 		     gnm_solver_constraint_get_part (c, sp, i,
 						     &lhs, &cl,
 						     &rhs, &cr);
-		     i++) {
+		     i++, cidx++) {
 			if (type) {
 				g_string_append_printf
 					(type, " %s\n",
 					 glpk_var_name (ssol, lhs));
 			} else {
 				gboolean ok;
+				char *name;
 
 				g_string_append_c (constraints, ' ');
 
+				name = g_strdup_printf ("C_%d", cidx);
+				gnm_sub_solver_name_constraint (ssol, cidx, name);
+				g_string_append (constraints, name);
+				g_string_append (constraints, ": ");
+				g_free (name);
+
 				ok = glpk_affine_func
 					(constraints, lhs, ssol,
 					 x1, x2,
@@ -290,8 +302,13 @@ glpk_create_program (GnmSubSolver *ssol, GOIOContext *io_context, GError **err)
 				"\\ Created by Gnumeric %s\n\n",
 				GNM_VERSION_FULL);
 	go_string_append_gstring (prg, objfunc);
+
 	g_string_append (prg, "\nSubject to\n");
 	go_string_append_gstring (prg, constraints);
+
+	g_string_append (prg, "\nBounds\n");
+	go_string_append_gstring (prg, bounds);
+
 	if (integers->len > 0) {
 		g_string_append (prg, "\nGeneral\n");
 		go_string_append_gstring (prg, integers);
@@ -305,6 +322,7 @@ glpk_create_program (GnmSubSolver *ssol, GOIOContext *io_context, GError **err)
 fail:
 	g_string_free (objfunc, TRUE);
 	g_string_free (constraints, TRUE);
+	g_string_free (bounds, TRUE);
 	g_string_free (integers, TRUE);
 	g_string_free (binaries, TRUE);
 	g_free (x1);
@@ -323,8 +341,17 @@ glpk_file_save (GOFileSaver const *fs, GOIOContext *io_context,
 	GError *err = NULL;
 	GString *prg;
 	GnmLocale *locale;
+	GnmSolver *sol = NULL;
 	GnmSubSolver *ssol = g_object_get_data (G_OBJECT (fs), "solver");
 
+	if (!ssol) {
+		// Create a temporary solver just functional enough to
+		// write the program
+		Sheet *sheet = wb_view_cur_sheet (wb_view);
+		sol = glpk_solver_create (sheet->solver_parameters);
+		ssol = GNM_SUB_SOLVER (sol);
+	}
+
 	go_io_progress_message (io_context,
 				_("Writing glpk file..."));
 
@@ -347,4 +374,7 @@ fail:
 	go_io_progress_unset (io_context);
 	if (err)
 		g_error_free (err);
+
+	if (sol)
+		g_object_unref (sol);
 }
