@@ -1,6 +1,6 @@
 #include <gnumeric-config.h>
 #include "gnumeric.h"
-#include <tools/gnm-solver.h>
+#include "boot.h"
 #include "cell.h"
 #include "sheet.h"
 #include "value.h"
@@ -22,7 +22,7 @@
 typedef struct {
 	GnmSubSolver *parent;
 	char *result_filename;
-	GnmSheetRange srinput;
+	char *ranges_filename;
 } GnmGlpk;
 
 static void
@@ -34,6 +34,11 @@ gnm_glpk_cleanup (GnmGlpk *lp)
 		g_free (lp->result_filename);
 		lp->result_filename = NULL;
 	}
+	if (lp->ranges_filename) {
+		g_unlink (lp->ranges_filename);
+		g_free (lp->ranges_filename);
+		lp->ranges_filename = NULL;
+	}
 }
 
 static void
@@ -62,21 +67,56 @@ write_program (GnmSolver *sol, WorkbookControl *wbc, GError **err)
 				  err);
 }
 
+static char **
+my_strsplit (const char *line)
+{
+	GPtrArray *res = g_ptr_array_new ();
+
+	while (1) {
+		const char *end;
+
+		while (g_ascii_isspace (*line))
+			line++;
+
+		if (!*line)
+			break;
+
+		end = line;
+		while (*end && !g_ascii_isspace (*end))
+			end++;
+
+		g_ptr_array_add (res, g_strndup (line, end - line));
+		line = end;
+	}
+	g_ptr_array_add (res, NULL);
+
+	return (char **)g_ptr_array_free (res, FALSE);
+}
+
+static gnm_float
+parse_number (const char *s)
+{
+	if (strcmp (s, ".") == 0)
+		return 0;
+	return g_ascii_strtod (s, NULL);
+}
+
 static void
 gnm_glpk_read_solution (GnmGlpk *lp)
 {
 	GnmSubSolver *subsol = lp->parent;
 	GnmSolver *sol = GNM_SOLVER (subsol);
 	GsfInput *input;
-	GsfInputTextline *tl;
+	GsfInputTextline *tl = NULL;
 	const char *line;
 	unsigned rows, cols, c, r;
 	int pstat, dstat;
 	gnm_float val;
-	GnmSolverResult *result;
-	int width, height;
+	GnmSolverResult *result = NULL;
+	GnmSolverSensitivity *sensitivity = NULL;
 	gboolean has_integer;
 	GSList *l;
+	enum { SEC_UNKNOWN, SEC_ROWS, SEC_COLUMNS } state;
 
 	/*
 	 * glpsol's output format is different if there are any integer
@@ -91,15 +131,14 @@ gnm_glpk_read_solution (GnmGlpk *lp)
 
 	input = gsf_input_stdio_new (lp->result_filename, NULL);
 	if (!input)
-		return;
-
+		goto fail;
 	tl = GSF_INPUT_TEXTLINE (gsf_input_textline_new (input));
 	g_object_unref (input);
 
-	width = range_width (&lp->srinput.range);
-	height = range_height (&lp->srinput.range);
 	result = g_object_new (GNM_SOLVER_RESULT_TYPE, NULL);
-	result->solution = value_new_array_empty (width, height);
+	result->solution = g_new0 (gnm_float, sol->input_cells->len);
+
+	sensitivity = gnm_solver_sensitivity_new (sol);
 
 	if ((line = gsf_input_textline_utf8_gets (tl)) == NULL)
 		goto fail;
@@ -133,16 +172,28 @@ gnm_glpk_read_solution (GnmGlpk *lp)
 		goto fail;
 	}
 
-	for (r = 1; r <= rows; r++) {
+	for (r = 0; r < rows; r++) {
+		gnm_float pval, dval;
+		unsigned rstat;
+		unsigned cidx = r;
+
 		if ((line = gsf_input_textline_utf8_gets (tl)) == NULL)
 			goto fail;
-		/* Ignore the line */
+
+		if (has_integer)
+			continue;
+
+		if (sscanf (line, "%u %" GNM_SCANF_g " %" GNM_SCANF_g,
+			    &rstat, &pval, &dval) != 3)
+			goto fail;
+
+		sensitivity->constraints[cidx].shadow_price = dval;
 	}
 
 	for (c = 0; c < cols; c++) {
 		gnm_float pval, dval;
 		unsigned cstat;
-		int x, y;
+		unsigned idx = c;
 
 		if ((line = gsf_input_textline_utf8_gets (tl)) == NULL)
 			goto fail;
@@ -153,22 +204,104 @@ gnm_glpk_read_solution (GnmGlpk *lp)
 			      &cstat, &pval, &dval) != 3)
 			goto fail;
 
-		x = c % width;
-		y = c / width;
-		value_array_set (result->solution, x, y,
-				 value_new_float (pval));
+		result->solution[idx] = pval;
+		if (!has_integer)
+			sensitivity->vars[idx].reduced_cost = dval;
 	}
 
+	g_object_unref (tl);
+	tl = NULL;
+
+	// ----------------------------------------
+
+	if (!lp->ranges_filename)
+		goto done;
+
+	input = gsf_input_stdio_new (lp->ranges_filename, NULL);
+	if (!input)
+		goto fail;
+	tl = GSF_INPUT_TEXTLINE (gsf_input_textline_new (input));
+	g_object_unref (input);
+
+	state = SEC_UNKNOWN;
+	// We are reading a file intended for human consumption.
+	// That is unfortunately because it implies rounding, for example.
+	// The information does not appear to be available elsewhere.
+
+	while ((line = gsf_input_textline_utf8_gets (tl)) != NULL) {
+		gchar **items, **items2 = NULL;
+		int len, len2 = 0;
+
+		if (g_str_has_prefix (line, "   No. Row name")) {
+			state = SEC_ROWS;
+			continue;
+		} else if (g_str_has_prefix (line, "   No. Column name")) {
+			state = SEC_COLUMNS;
+			continue;
+		} else if (g_ascii_isalpha (line[0])) {
+			state = SEC_UNKNOWN;
+			continue;
+		}
+
+		if (state == SEC_UNKNOWN)
+			continue;
+
+		items = my_strsplit (line);
+		len = g_strv_length (items);
+
+		if (len == 10 && g_ascii_isdigit (items[0][0])) {
+			line = gsf_input_textline_utf8_gets (tl);
+			if (line) {
+				items2 = my_strsplit (line);
+				len2 = g_strv_length (items2);
+			}
+		}
+
+		if (len == 10 && len2 == 6 && state == SEC_COLUMNS) {
+			gnm_float low = parse_number (items[7]);
+			gnm_float high = parse_number (items2[3]);
+			GnmCell const *cell = gnm_sub_solver_find_cell (lp->parent, items[1]);
+			int idx = gnm_solver_cell_index (sol, cell);
+			if (idx >= 0) {
+				sensitivity->vars[idx].low = low;
+				sensitivity->vars[idx].high = high;
+			}
+		}
+
+		if (len == 10 && len2 == 6 && state == SEC_ROWS) {
+			gnm_float low = parse_number (items[6]);
+			gnm_float high = parse_number (items2[2]);
+			int cidx = gnm_sub_solver_find_constraint (lp->parent, items[1]);
+			if (cidx >= 0) {
+				sensitivity->constraints[cidx].low = low;
+				sensitivity->constraints[cidx].high = high;
+			}
+		}
+		
+		g_strfreev (items);
+		g_strfreev (items2);
+
+	}
+
+	g_object_unref (tl);
+
+	// ----------------------------------------
+done:
 	gnm_solver_set_status (sol, GNM_SOLVER_STATUS_DONE);
 	g_object_set (subsol, "result", result, NULL);
 	g_object_unref (result);
+	g_object_set (subsol, "sensitivity", sensitivity, NULL);
+	g_object_unref (sensitivity);
 
-	g_object_unref (tl);
 	return;
 
 fail:
-	g_object_unref (tl);
-	g_object_unref (result);
+	if (tl)
+		g_object_unref (tl);
+	if (result)
+		g_object_unref (result);
+	if (sensitivity)
+		g_object_unref (sensitivity);
 	gnm_solver_set_status (sol, GNM_SOLVER_STATUS_ERROR);
 }
 
@@ -238,9 +371,18 @@ gnm_glpk_prepare (GnmSolver *sol, WorkbookControl *wbc, GError **err,
 			     _("Failed to create file for solution"));
 		goto fail;
 	}
-
 	close (fd);
 
+	if (sol->params->options.sensitivity_report) {
+		fd = g_file_open_tmp ("program-XXXXXX.ran", &lp->ranges_filename, err);
+		if (fd == -1) {
+			g_set_error (err, G_FILE_ERROR, 0,
+				     _("Failed to create file for sensitivity report"));
+			goto fail;
+		}
+		close (fd);
+	}
+
 	gnm_solver_set_status (sol, GNM_SOLVER_STATUS_PREPARED);
 
 	return TRUE;
@@ -257,7 +399,7 @@ gnm_glpk_start (GnmSolver *sol, WorkbookControl *wbc, GError **err,
 {
 	GnmSubSolver *subsol = GNM_SUB_SOLVER (sol);
 	gboolean ok;
-	gchar *argv[7];
+	gchar *argv[9];
 	int argc = 0;
 	GnmSolverParameters *param = sol->params;
 	const char *binary;
@@ -274,6 +416,10 @@ gnm_glpk_start (GnmSolver *sol, WorkbookControl *wbc, GError **err,
 				 : "--noscale");
 	argv[argc++] = (gchar *)"--write";
 	argv[argc++] = lp->result_filename;
+	if (lp->ranges_filename) {
+		argv[argc++] = (gchar *)"--ranges";
+		argv[argc++] = lp->ranges_filename;
+	}
 	argv[argc++] = (gchar *)"--cpxlp";
 	argv[argc++] = subsol->program_filename;
 	argv[argc] = NULL;
@@ -311,9 +457,26 @@ gnm_glpk_stop (GnmSolver *sol, GError *err, GnmGlpk *lp)
 	return TRUE;
 }
 
-gboolean
-glpk_solver_factory_functional (GnmSolverFactory *factory,
-				WBCGtk *wbcg);
+GnmSolver *
+glpk_solver_create (GnmSolverParameters *params)
+{
+	GnmSolver *res = g_object_new (GNM_SUB_SOLVER_TYPE,
+				       "params", params,
+				       NULL);
+	GnmGlpk *lp = g_new0 (GnmGlpk, 1);
+
+	lp->parent = GNM_SUB_SOLVER (res);
+
+	g_signal_connect (res, "prepare", G_CALLBACK (gnm_glpk_prepare), lp);
+	g_signal_connect (res, "start", G_CALLBACK (gnm_glpk_start), lp);
+	g_signal_connect (res, "stop", G_CALLBACK (gnm_glpk_stop), lp);
+	g_signal_connect (res, "child-exit", G_CALLBACK (gnm_glpk_child_exit), lp);
+
+	g_object_set_data_full (G_OBJECT (res), PRIVATE_KEY, lp,
+				(GDestroyNotify)gnm_glpk_final);
+
+	return res;
+}
 
 gboolean
 glpk_solver_factory_functional (GnmSolverFactory *factory,
@@ -347,30 +510,8 @@ glpk_solver_factory_functional (GnmSolverFactory *factory,
 	return FALSE;
 }
 
-
-GnmSolver *
-glpk_solver_factory (GnmSolverFactory *factory, GnmSolverParameters *params);
-
 GnmSolver *
 glpk_solver_factory (GnmSolverFactory *factory, GnmSolverParameters *params)
 {
-	GnmSolver *res = g_object_new (GNM_SUB_SOLVER_TYPE,
-				       "params", params,
-				       NULL);
-	GnmGlpk *lp = g_new0 (GnmGlpk, 1);
-
-	lp->parent = GNM_SUB_SOLVER (res);
-	gnm_sheet_range_from_value (&lp->srinput,
-				    gnm_solver_param_get_input (params));
-	if (!lp->srinput.sheet) lp->srinput.sheet = params->sheet;
-
-	g_signal_connect (res, "prepare", G_CALLBACK (gnm_glpk_prepare), lp);
-	g_signal_connect (res, "start", G_CALLBACK (gnm_glpk_start), lp);
-	g_signal_connect (res, "stop", G_CALLBACK (gnm_glpk_stop), lp);
-	g_signal_connect (res, "child-exit", G_CALLBACK (gnm_glpk_child_exit), lp);
-
-	g_object_set_data_full (G_OBJECT (res), PRIVATE_KEY, lp,
-				(GDestroyNotify)gnm_glpk_final);
-
-	return res;
+	return glpk_solver_create (params);
 }
