@@ -213,6 +213,7 @@ lpsolve_create_program (GnmSubSolver *ssol, GOIOContext *io_context, GError **er
 		const char *op = NULL;
 		const char *type = NULL;
 		int i;
+		int cidx = 0;
 		gnm_float cl, cr;
 		GnmCell *lhs, *rhs;
 
@@ -240,7 +241,7 @@ lpsolve_create_program (GnmSubSolver *ssol, GOIOContext *io_context, GError **er
 		     gnm_solver_constraint_get_part (c, sp, i,
 						     &lhs, &cl,
 						     &rhs, &cr);
-		     i++) {
+		     i++, cidx++) {
 			if (type) {
 				g_string_append (declarations, type);
 				g_string_append_c (declarations, ' ');
@@ -249,6 +250,12 @@ lpsolve_create_program (GnmSubSolver *ssol, GOIOContext *io_context, GError **er
 			} else {
 				gboolean ok;
 
+				char *name = g_strdup_printf ("CONSTR_%d", cidx);
+				g_string_append (constraints, name);
+				g_string_append (constraints, ": ");
+				gnm_sub_solver_name_constraint (ssol, cidx, name);
+				g_free (name);
+
 				ok = lpsolve_affine_func
 					(constraints, lhs, ssol,
 					 x1, x2,
@@ -308,8 +315,17 @@ lpsolve_file_save (GOFileSaver const *fs, GOIOContext *io_context,
 	GError *err = NULL;
 	GString *prg;
 	GnmLocale *locale;
+	GnmSolver *sol = NULL;
 	GnmSubSolver *ssol = g_object_get_data (G_OBJECT (fs), "solver");
 
+	if (!ssol) {
+		// Create a temporary solver just functional enough to
+		// write the program
+		Sheet *sheet = wb_view_cur_sheet (wb_view);
+		sol = lpsolve_solver_create (sheet->solver_parameters);
+		ssol = GNM_SUB_SOLVER (sol);
+	}
+
 	go_io_progress_message (io_context,
 				_("Writing lpsolve file..."));
 
@@ -332,4 +348,7 @@ fail:
 	go_io_progress_unset (io_context);
 	if (err)
 		g_error_free (err);
+
+	if (sol)
+		g_object_unref (sol);
 }
