@@ -402,8 +402,8 @@ callback_function_collect (GnmEvalPos const *ep, GnmValue const *value,
 	return NULL;
 }
 
-/*
- * collect_floats:
+/**
+ * collect_floats: (skip):
  *
  * exprlist:       List of expressions to evaluate.
  * cr:             Current location (for resolving relative cells).
@@ -427,7 +427,7 @@ callback_function_collect (GnmEvalPos const *ep, GnmValue const *value,
  * Evaluate a list of expressions and return the result as an array of
  * gnm_float.
  */
-static gnm_float *
+gnm_float *
 collect_floats (int argc, GnmExprConstPtr const *argv,
 		GnmEvalPos const *ep, CollectFlags flags,
 		int *n, GnmValue **error, GSList **info,
