@@ -130,7 +130,7 @@ wilcoxon_mann_whitney_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	data = g_new0 (analysis_tools_data_generic_b_t, 1);
 	dao  = parse_output (state, NULL);
 
-	data->wbc = WORKBOOK_CONTROL (state->wbcg);
+	data->wbc = GNM_WBC (state->wbcg);
 
 	data->range_1 = gnm_expr_entry_parse_as_value
 		(GNM_EXPR_ENTRY (state->input_entry), state->sheet);
@@ -141,7 +141,7 @@ wilcoxon_mann_whitney_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	w = go_gtk_builder_get_widget (state->gui, "labels_button");
         data->labels = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w));
 
-	if (cmd_analysis_tool (WORKBOOK_CONTROL (state->wbcg), state->sheet,
+	if (cmd_analysis_tool (GNM_WBC (state->wbcg), state->sheet,
 			       dao, data,
 			       analysis_tool_wilcoxon_mann_whitney_engine, TRUE)) {
 		char   *text;
@@ -178,7 +178,7 @@ dialog_wilcoxon_m_w_tool (WBCGtk *wbcg, Sheet *sheet)
 		return 1;
 
 	/* Only pop up one copy per workbook */
-	if (gnumeric_dialog_raise_if_exists (wbcg, WILCOXON_MANN_WHITNEY_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, WILCOXON_MANN_WHITNEY_KEY))
 		return 0;
 
 	state = g_new0 (GenericToolState, 1);
