@@ -85,7 +85,7 @@ dialog_col_row (WBCGtk *wbcg,  char const *operation,
 
 	g_return_if_fail (wbcg != NULL);
 
-	if (gnumeric_dialog_raise_if_exists (wbcg, COL_ROW_DIALOG_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, COL_ROW_DIALOG_KEY))
 		return;
 	gui = gnm_gtk_builder_load ("colrow.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
@@ -109,7 +109,7 @@ dialog_col_row (WBCGtk *wbcg,  char const *operation,
 		"clicked",
 		G_CALLBACK (cb_dialog_col_row_cancel_clicked), state);
 
-	gnumeric_init_help_button (
+	gnm_init_help_button (
 		go_gtk_builder_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_GROUP_UNGROUP);
 
@@ -119,7 +119,7 @@ dialog_col_row (WBCGtk *wbcg,  char const *operation,
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify) cb_dialog_col_row_destroy);
 
-	gnumeric_keyed_dialog (wbcg, GTK_WINDOW (state->dialog),
+	gnm_keyed_dialog (wbcg, GTK_WINDOW (state->dialog),
 			       COL_ROW_DIALOG_KEY);
 	gtk_widget_show (state->dialog);
 }
