@@ -189,14 +189,14 @@ cb_dialog_col_width_apply_clicked (G_GNUC_UNUSED GtkWidget *button,
 
 	if (state->set_default_value) {
 		double points = value * 72./gnm_app_display_dpi_get (FALSE);
-		cmd_colrow_std_size (WORKBOOK_CONTROL (state->wbcg),
+		cmd_colrow_std_size (GNM_WBC (state->wbcg),
 				     state->sheet, TRUE, points);
 		dialog_col_width_load_value (state);
 	} else {
 		if (use_default)
 			size_pixels = 0;
 
-		workbook_cmd_resize_selected_colrow (WORKBOOK_CONTROL (state->wbcg),
+		workbook_cmd_resize_selected_colrow (GNM_WBC (state->wbcg),
 			state->sheet, TRUE, size_pixels);
 		dialog_col_width_load_value (state);
 	}
@@ -244,7 +244,7 @@ dialog_col_width (WBCGtk *wbcg, gboolean use_default)
 
 	g_return_if_fail (wbcg != NULL);
 
-	if (gnumeric_dialog_raise_if_exists (wbcg, COL_WIDTH_DIALOG_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, COL_WIDTH_DIALOG_KEY))
 		return;
 	gui = gnm_gtk_builder_load ("col-width.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
@@ -252,7 +252,7 @@ dialog_col_width (WBCGtk *wbcg, gboolean use_default)
 
 	state = g_new (ColWidthState, 1);
 	state->wbcg  = wbcg;
-	state->sv = wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
+	state->sv = wb_control_cur_sheet_view (GNM_WBC (wbcg));
 	state->sheet = sv_sheet (state->sv);
 	state->adjusting = FALSE;
 	state->dialog = go_gtk_builder_get_widget (gui, "dialog");
@@ -286,7 +286,7 @@ dialog_col_width (WBCGtk *wbcg, gboolean use_default)
 		"clicked",
 		G_CALLBACK (cb_dialog_col_width_cancel_clicked), state);
 
-	gnumeric_init_help_button (
+	gnm_init_help_button (
 		go_gtk_builder_get_widget (gui, "help_button"),
 		GNUMERIC_HELP_LINK_COL_WIDTH);
 
@@ -300,7 +300,7 @@ dialog_col_width (WBCGtk *wbcg, gboolean use_default)
 	g_object_set_data_full (G_OBJECT (state->dialog),
 				"state", state, (GDestroyNotify)g_free);
 
-	gnumeric_keyed_dialog (wbcg, GTK_WINDOW (state->dialog),
+	gnm_keyed_dialog (wbcg, GTK_WINDOW (state->dialog),
 			       COL_WIDTH_DIALOG_KEY);
 	gtk_widget_show (state->dialog);
 	g_object_unref (gui);
