@@ -82,7 +82,7 @@ cb_data_table_response (GtkWidget *dialog, gint response_id, GnmDialogDataTable
 	if (response_id == GTK_RESPONSE_HELP)
 		return;
 	if (response_id == GTK_RESPONSE_OK)
-		cmd_create_data_table (WORKBOOK_CONTROL (state->wbcg),
+		cmd_create_data_table (GNM_WBC (state->wbcg),
 			state->sheet, &state->input_range,
 			gnm_expr_entry_get_text	(state->col_entry),
 			gnm_expr_entry_get_text (state->row_entry));
@@ -106,12 +106,12 @@ data_table_init (GnmDialogDataTable *state, WBCGtk *wbcg)
 
 	g_signal_connect (G_OBJECT (state->dialog), "response",
 		G_CALLBACK (cb_data_table_response), state);
-	gnumeric_init_help_button (
+	gnm_init_help_button (
 		go_gtk_builder_get_widget (state->gui, "help"),
 		GNUMERIC_HELP_LINK_DATA_TABLE);
 
 	/* a candidate for merging into attach guru */
-	gnumeric_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
+	gnm_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
 		DIALOG_DATA_TABLE_KEY);
 	go_gtk_nonmodal_dialog (wbcg_toplevel (state->wbcg),
 		GTK_WINDOW (state->dialog));
@@ -137,10 +137,10 @@ dialog_data_table (WBCGtk *wbcg)
 	g_return_if_fail (wbcg != NULL);
 
 	if (wbc_gtk_get_guru (wbcg) ||
-	    gnumeric_dialog_raise_if_exists (wbcg, DIALOG_DATA_TABLE_KEY))
+	    gnm_dialog_raise_if_exists (wbcg, DIALOG_DATA_TABLE_KEY))
 		return;
 
-	sv = wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
+	sv = wb_control_cur_sheet_view (GNM_WBC (wbcg));
 	r = selection_first_range (sv, GO_CMD_CONTEXT (wbcg), _("Create Data Table"));
 	if (NULL == r)
 		return;
@@ -159,7 +159,7 @@ dialog_data_table (WBCGtk *wbcg)
 				       GO_CMD_CONTEXT (wbcg), _("Data Table")))
 		return;
 	if (cmd_cell_range_is_locked_effective
-	    (sheet, &input_range, WORKBOOK_CONTROL (wbcg),
+	    (sheet, &input_range, GNM_WBC (wbcg),
 					   _("Data Table")))
 		return;
 
