@@ -383,7 +383,7 @@ dhl_cb_ok (G_GNUC_UNUSED GtkWidget *button, HyperlinkState *state)
 	if (!success)
 		return;		/* Let user continue editing */
 
-	wb_control_sheet_focus (WORKBOOK_CONTROL (state->wbcg), state->sheet);
+	wb_control_sheet_focus (GNM_WBC (state->wbcg), state->sheet);
 
 	if (target) {
 		gnm_hlink_set_target (state->link, target);
@@ -397,12 +397,12 @@ dhl_cb_ok (G_GNUC_UNUSED GtkWidget *button, HyperlinkState *state)
 
 		if (state->is_new) {
 			cmdname = _("Add Hyperlink");
-			cmd_selection_hyperlink (WORKBOOK_CONTROL (state->wbcg),
+			cmd_selection_hyperlink (GNM_WBC (state->wbcg),
 						 style,
 						 cmdname, target);
 		} else {
 			cmdname = _("Edit Hyperlink");
-			cmd_selection_hyperlink (WORKBOOK_CONTROL (state->wbcg),
+			cmd_selection_hyperlink (GNM_WBC (state->wbcg),
 						 style,
 						 cmdname, NULL);
 			g_free (target);
@@ -411,7 +411,7 @@ dhl_cb_ok (G_GNUC_UNUSED GtkWidget *button, HyperlinkState *state)
 		style = gnm_style_new ();
 		gnm_style_set_hlink (style, NULL);
 		cmdname = _("Remove Hyperlink");
-		cmd_selection_hyperlink (WORKBOOK_CONTROL (state->wbcg), style,
+		cmd_selection_hyperlink (GNM_WBC (state->wbcg), style,
 					 cmdname, NULL);
 	}
 	gtk_widget_destroy (state->dialog);
@@ -513,7 +513,7 @@ dhl_init (HyperlinkState *state)
 			  G_CALLBACK (dhl_cb_ok), state);
 	gtk_window_set_default (GTK_WINDOW (state->dialog), w);
 
-	gnumeric_init_help_button (
+	gnm_init_help_button (
 		go_gtk_builder_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_HYPERLINK);
 
@@ -580,7 +580,7 @@ dialog_hyperlink (WBCGtk *wbcg, SheetControl *sc)
 
 	g_return_if_fail (wbcg != NULL);
 
-	if (gnumeric_dialog_raise_if_exists (wbcg, DIALOG_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, DIALOG_KEY))
 		return;
 
 	gui = gnm_gtk_builder_load ("hyperlink.ui", NULL, GO_CMD_CONTEXT (wbcg));
@@ -589,7 +589,7 @@ dialog_hyperlink (WBCGtk *wbcg, SheetControl *sc)
 
 	state = g_new (HyperlinkState, 1);
 	state->wbcg  = wbcg;
-	state->wb   = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
+	state->wb   = wb_control_get_workbook (GNM_WBC (wbcg));
 	state->sc   = sc;
 	state->gui  = gui;
         state->dialog = go_gtk_builder_get_widget (state->gui, "hyperlink-dialog");
@@ -627,7 +627,7 @@ dialog_hyperlink (WBCGtk *wbcg, SheetControl *sc)
 	dhl_set_tip (state);
 
 	/* a candidate for merging into attach guru */
-	gnumeric_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
+	gnm_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
 			       DIALOG_KEY);
 	go_gtk_nonmodal_dialog (wbcg_toplevel (state->wbcg),
 				   GTK_WINDOW (state->dialog));
