@@ -32,22 +32,22 @@ xml2c (xmlChar *src)
 	return dst;
 }
 
-typedef GOPluginServiceSimpleClass	PluginServiceFunctionGroupClass;
-struct _PluginServiceFunctionGroup {
+typedef GOPluginServiceSimpleClass GnmPluginServiceFunctionGroupClass;
+struct GnmPluginServiceFunctionGroup_ {
 	GOPluginServiceSimple	base;
 
 	gchar *category_name, *translated_category_name;
 	GSList *function_name_list;
 
 	GnmFuncGroup *func_group;
-	PluginServiceFunctionGroupCallbacks cbs;
+	GnmPluginServiceFunctionGroupCallbacks cbs;
 	char *textdomain;
 };
 
 static void
 plugin_service_function_group_finalize (GObject *obj)
 {
-	PluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (obj);
+	GnmPluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (obj);
 	GObjectClass *parent_class;
 
 	g_free (sfg->category_name);
@@ -116,7 +116,7 @@ plugin_service_function_group_read_xml (GOPluginService *service, xmlNode *tree,
 		GO_SLIST_REVERSE (function_name_list);
 	}
 	if (category_name != NULL && function_name_list != NULL) {
-		PluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
+		GnmPluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
 
 		sfg->category_name = category_name;
 		sfg->translated_category_name = translated_category_name;
@@ -149,7 +149,7 @@ plugin_service_function_group_func_desc_load (GnmFunc const *fn_def,
 					      GnmFuncDescriptor *res)
 {
 	GOPluginService	*service = gnm_func_get_user_data (fn_def);
-	PluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
+	GnmPluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
 	GOErrorInfo *error = NULL;
 
 	g_return_val_if_fail (fn_def != NULL, FALSE);
@@ -177,7 +177,7 @@ plugin_service_function_group_func_ref_notify (GnmFunc *fn_def, int refcount)
 	GOPluginService *service;
 
 	service = gnm_func_get_user_data (fn_def);
-	g_return_if_fail (IS_GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service));
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (service));
 	if (refcount == 0) {
 		go_plugin_use_unref (service->plugin);
 	} else {
@@ -199,7 +199,7 @@ delayed_ref_notify (GOPlugin *plugin, GnmFunc *fd)
 static void
 plugin_service_function_group_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
-	PluginServiceFunctionGroup *sfg =
+	GnmPluginServiceFunctionGroup *sfg =
 		GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
@@ -241,7 +241,7 @@ plugin_service_function_group_activate (GOPluginService *service, GOErrorInfo **
 static void
 plugin_service_function_group_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
-	PluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
+	GnmPluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
 
 	if (gnm_debug_flag ("plugin-func"))
 		g_printerr ("Deactivating group %s\n", sfg->category_name);
@@ -256,7 +256,7 @@ plugin_service_function_group_deactivate (GOPluginService *service, GOErrorInfo
 static char *
 plugin_service_function_group_get_description (GOPluginService *service)
 {
-	PluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
+	GnmPluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
 	int n_functions;
 	char const *category_name;
 
@@ -273,7 +273,7 @@ plugin_service_function_group_get_description (GOPluginService *service)
 }
 
 static void
-plugin_service_function_group_init (PluginServiceFunctionGroup *s)
+plugin_service_function_group_init (GnmPluginServiceFunctionGroup *s)
 {
 	GO_PLUGIN_SERVICE (s)->cbs_ptr = &s->cbs;
 	s->category_name = NULL;
@@ -295,7 +295,7 @@ plugin_service_function_group_class_init (GObjectClass *gobject_class)
 	plugin_service_class->get_description = plugin_service_function_group_get_description;
 }
 
-GSF_CLASS (PluginServiceFunctionGroup, plugin_service_function_group,
+GSF_CLASS (GnmPluginServiceFunctionGroup, gnm_plugin_service_function_group,
            plugin_service_function_group_class_init, plugin_service_function_group_init,
            GO_TYPE_PLUGIN_SERVICE_SIMPLE)
 
@@ -305,14 +305,14 @@ GSF_CLASS (PluginServiceFunctionGroup, plugin_service_function_group,
  * PluginServiceUI
  */
 typedef GOPluginServiceSimpleClass PluginServiceUIClass;
-struct _PluginServiceUI {
+struct GnmPluginServiceUI_ {
 	GOPluginServiceSimple base;
 
 	char *file_name;
 	GSList *actions;
 
 	gpointer layout_id;
-	PluginServiceUICallbacks cbs;
+	GnmPluginServiceUICallbacks cbs;
 };
 
 static void
@@ -528,7 +528,7 @@ plugin_service_ui_class_init (GObjectClass *gobject_class)
 	plugin_service_class->get_description = plugin_service_ui_get_description;
 }
 
-GSF_CLASS (PluginServiceUI, plugin_service_ui,
+GSF_CLASS (PluginServiceUI, gnm_plugin_service_ui,
            plugin_service_ui_class_init, plugin_service_ui_init,
            GO_TYPE_PLUGIN_SERVICE_SIMPLE)
 
@@ -538,12 +538,12 @@ GSF_CLASS (PluginServiceUI, plugin_service_ui,
  * PluginServiceSolver
  */
 typedef GOPluginServiceClass PluginServiceSolverClass;
-struct _PluginServiceSolver {
+struct GnmPluginServiceSolver_ {
 	GOPluginService base;
 
 	GnmSolverFactory *factory;
 
-	PluginServiceSolverCallbacks cbs;
+	GnmPluginServiceSolverCallbacks cbs;
 };
 
 static GnmSolver *
@@ -710,7 +710,7 @@ plugin_service_solver_class_init (GObjectClass *gobject_class)
 	plugin_service_class->get_description = plugin_service_solver_get_description;
 }
 
-GSF_CLASS (PluginServiceSolver, plugin_service_solver,
+GSF_CLASS (PluginServiceSolver, gnm_plugin_service_solver,
            plugin_service_solver_class_init, plugin_service_solver_init,
            GO_TYPE_PLUGIN_SERVICE)
 
@@ -745,7 +745,7 @@ gnm_plugin_loader_module_func_desc_load (GOPluginService *service,
 	ServiceLoaderDataFunctionGroup *loader_data;
 	gpointer func_index_ptr;
 
-	g_return_val_if_fail (IS_GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service), FALSE);
+	g_return_val_if_fail (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (service), FALSE);
 	g_return_val_if_fail (name != NULL, FALSE);
 
 	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
@@ -766,14 +766,14 @@ gnm_plugin_loader_module_load_service_function_group (GOPluginLoader  *loader,
 	gchar *fn_info_array_name;
 	GnmFuncDescriptor *module_fn_info_array = NULL;
 
-	g_return_if_fail (IS_GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service));
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (service));
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	fn_info_array_name = g_strconcat (
 		go_plugin_service_get_id (service), "_functions", NULL);
 	g_module_symbol (loader_module->handle, fn_info_array_name, (gpointer) &module_fn_info_array);
 	if (module_fn_info_array != NULL) {
-		PluginServiceFunctionGroupCallbacks *cbs;
+		GnmPluginServiceFunctionGroupCallbacks *cbs;
 		ServiceLoaderDataFunctionGroup *loader_data;
 		gint i;
 
@@ -807,7 +807,7 @@ gnm_plugin_loader_module_load_service_function_group (GOPluginLoader  *loader,
  */
 
 typedef struct {
-	ModulePluginUIActions *module_ui_actions_array;
+	GnmModulePluginUIActions *module_ui_actions_array;
 	GHashTable *ui_actions_hash;
 } ServiceLoaderDataUI;
 
@@ -830,7 +830,7 @@ gnm_plugin_loader_module_func_exec_action (GOPluginService *service,
 	gpointer action_index_ptr;
 	int action_index;
 
-	g_return_if_fail (IS_GNM_PLUGIN_SERVICE_UI (service));
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_UI (service));
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
@@ -851,12 +851,12 @@ gnm_plugin_loader_module_load_service_ui (GOPluginLoader *loader,
 {
 	GnmPluginLoaderModule *loader_module = GNM_PLUGIN_LOADER_MODULE (loader);
 	char *ui_actions_array_name;
-	ModulePluginUIActions *module_ui_actions_array = NULL;
-	PluginServiceUICallbacks *cbs;
+	GnmModulePluginUIActions *module_ui_actions_array = NULL;
+	GnmPluginServiceUICallbacks *cbs;
 	ServiceLoaderDataUI *loader_data;
 	gint i;
 
-	g_return_if_fail (IS_GNM_PLUGIN_SERVICE_UI (service));
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_UI (service));
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	ui_actions_array_name = g_strconcat (
@@ -894,12 +894,12 @@ gnm_plugin_loader_module_load_service_solver (GOPluginLoader *loader,
 {
 	GnmPluginLoaderModule *loader_module =
 		GNM_PLUGIN_LOADER_MODULE (loader);
-	PluginServiceSolverCallbacks *cbs;
+	GnmPluginServiceSolverCallbacks *cbs;
 	char *symname;
 	GnmSolverCreator creator;
 	GnmSolverFactoryFunctional functional;
 
-	g_return_if_fail (IS_GNM_PLUGIN_SERVICE_SOLVER (service));
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_SOLVER (service));
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 
@@ -929,11 +929,11 @@ gnm_plugin_loader_module_load_service_solver (GOPluginLoader *loader,
 static gboolean
 gplm_service_load (GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err)
 {
-	if (IS_GNM_PLUGIN_SERVICE_FUNCTION_GROUP (s))
+	if (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (s))
 		gnm_plugin_loader_module_load_service_function_group (l, s, err);
-	else if (IS_GNM_PLUGIN_SERVICE_UI (s))
+	else if (GNM_IS_PLUGIN_SERVICE_UI (s))
 		gnm_plugin_loader_module_load_service_ui (l, s, err);
-	else if (IS_GNM_PLUGIN_SERVICE_SOLVER (s))
+	else if (GNM_IS_PLUGIN_SERVICE_SOLVER (s))
 		gnm_plugin_loader_module_load_service_solver (l, s, err);
 	else
 		return FALSE;
@@ -943,14 +943,14 @@ gplm_service_load (GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err)
 static gboolean
 gplm_service_unload (GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err)
 {
-	if (IS_GNM_PLUGIN_SERVICE_FUNCTION_GROUP (s)) {
-		PluginServiceFunctionGroupCallbacks *cbs = go_plugin_service_get_cbs (s);
+	if (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (s)) {
+		GnmPluginServiceFunctionGroupCallbacks *cbs = go_plugin_service_get_cbs (s);
 		cbs->func_desc_load = NULL;
-	} else if (IS_GNM_PLUGIN_SERVICE_UI (s)) {
-		PluginServiceUICallbacks *cbs = go_plugin_service_get_cbs (s);
+	} else if (GNM_IS_PLUGIN_SERVICE_UI (s)) {
+		GnmPluginServiceUICallbacks *cbs = go_plugin_service_get_cbs (s);
 		cbs->plugin_func_exec_action = NULL;
-	} else if (IS_GNM_PLUGIN_SERVICE_SOLVER (s)) {
-		PluginServiceSolverCallbacks *cbs =
+	} else if (GNM_IS_PLUGIN_SERVICE_SOLVER (s)) {
+		GnmPluginServiceSolverCallbacks *cbs =
 			go_plugin_service_get_cbs (s);
 		cbs->creator = NULL;
 		cbs->functional = NULL;
