@@ -651,7 +651,6 @@ item_cursor_selection_motion (GocItem *item, double x_, double y_)
 	int style, button;
 	gint64 x = x_ * canvas->pixels_per_unit, y = y_ * canvas->pixels_per_unit;
 	GnmItemCursor *special_cursor;
-	GdkEvent *event = goc_canvas_get_cur_event (item->canvas);
 
 	if (ic->drag_button < 0) {
 		item_cursor_set_cursor (canvas, ic, x, y);
@@ -669,7 +668,7 @@ item_cursor_selection_motion (GocItem *item, double x_, double y_)
 
 	button = ic->drag_button;
 	ic->drag_button = -1;
-	gnm_simple_canvas_ungrab (item, gdk_event_get_time (event));
+	gnm_simple_canvas_ungrab (item);
 
 	scg_special_cursor_start (ic->scg, style, button);
 	special_cursor = pane->cursor.special;
@@ -714,9 +713,7 @@ item_cursor_selection_motion (GocItem *item, double x_, double y_)
 
 	scg_special_cursor_bound_set (ic->scg, &ic->pos);
 
-	gnm_simple_canvas_grab (GOC_ITEM (special_cursor),
-		GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_PRESS_MASK,
-		NULL, gdk_event_get_time (event));
+	gnm_simple_canvas_grab (GOC_ITEM (special_cursor));
 	gnm_pane_slide_init (pane);
 
 	goc_item_bounds_changed (GOC_ITEM (ic));
@@ -1111,9 +1108,7 @@ item_cursor_button_pressed (GocItem *item, int button, double x_, double y_)
 
 			ic->drag_button = button;
 			ic->drag_button_state = bevent->state;
-			gnm_simple_canvas_grab (item,
-				GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_PRESS_MASK,
-				NULL, gdk_event_get_time (event));
+			gnm_simple_canvas_grab (item);
 		} else
 			scg_context_menu (ic->scg, event, FALSE, FALSE);
 		return TRUE;
@@ -1149,7 +1144,7 @@ item_cursor_button2_pressed (GocItem *item, int button, double x_, double y_)
 			return TRUE;
 
 		ic->drag_button = -1;
-		gnm_simple_canvas_ungrab (item, gdk_event_get_time (event));
+		gnm_simple_canvas_ungrab (item);
 
 		if (sheet_is_region_empty (sheet, &ic->pos))
 			return TRUE;
@@ -1364,7 +1359,7 @@ item_cursor_button_released (GocItem *item, int button, G_GNUC_UNUSED double x,
 
 		/* Double clicks may have already released the drag prep */
 		if (ic->drag_button >= 0) {
-			gnm_simple_canvas_ungrab (item, gdk_event_get_time (event));
+			gnm_simple_canvas_ungrab (item);
 			ic->drag_button = -1;
 		}
 		go_cmd_context_progress_message_set (GO_CMD_CONTEXT (wbcg),
@@ -1376,7 +1371,7 @@ item_cursor_button_released (GocItem *item, int button, G_GNUC_UNUSED double x,
 			return TRUE;
 
 		gnm_pane_slide_stop (GNM_PANE (item->canvas));
-		gnm_simple_canvas_ungrab (item, gdk_event_get_time (event));
+		gnm_simple_canvas_ungrab (item);
 		item_cursor_do_drop (ic, event);
 
 		go_cmd_context_progress_message_set (GO_CMD_CONTEXT (wbcg),
@@ -1392,7 +1387,7 @@ item_cursor_button_released (GocItem *item, int button, G_GNUC_UNUSED double x,
 		SheetControlGUI *scg = ic->scg;
 
 		gnm_pane_slide_stop (GNM_PANE (item->canvas));
-		gnm_simple_canvas_ungrab (item, gdk_event_get_time (event));
+		gnm_simple_canvas_ungrab (item);
 
 		cmd_autofill (scg_wbc (scg), scg_sheet (scg), default_increment,
 			      ic->pos.start.col, ic->pos.start.row,
