@@ -454,6 +454,14 @@ gnm_float gnm_lbeta(gnm_float a, gnm_float b)
 
 /* ------------------------------------------------------------------------ */
 
+gnm_float
+gnm_gammax (gnm_float x, int *exp2)
+{
+	GnmQuad r;
+	(void) qgammaf (x, &r, exp2);
+	return gnm_quad_value (&r);
+}
+
 /**
  * gnm_gamma:
  * @x: a number
@@ -464,18 +472,21 @@ gnm_float gnm_lbeta(gnm_float a, gnm_float b)
 gnm_float
 gnm_gamma (gnm_float x)
 {
-	GnmQuad r;
 	int e;
-
-	switch (qgammaf (x, &r, &e)) {
-	case 0: return ldexp (gnm_quad_value (&r), e);
-	case 1: return gnm_pinf;
-	default: return gnm_nan;
-	}
+	gnm_float r = gnm_gammax (x, &e);
+	return gnm_ldexp (r, e);
 }
 
 /* ------------------------------------------------------------------------- */
 
+gnm_float
+gnm_factx (gnm_float x, int *exp2)
+{
+	GnmQuad r;
+	(void)qfactf (x, &r, exp2);
+	return gnm_quad_value (&r);
+}
+
 /**
  * gnm_fact:
  * @x: number
@@ -485,14 +496,9 @@ gnm_gamma (gnm_float x)
 gnm_float
 gnm_fact (gnm_float x)
 {
-	GnmQuad r;
 	int e;
-
-	switch (qfactf (x, &r, &e)) {
-	case 0: return ldexp (gnm_quad_value (&r), e);
-	case 1: return gnm_pinf;
-	default: return gnm_nan;
-	}
+	gnm_float r = gnm_factx (x, &e);
+	return gnm_ldexp (r, e);
 }
 
 /* ------------------------------------------------------------------------- */
@@ -561,7 +567,7 @@ gnm_beta (gnm_float a, gnm_float b)
 	int e;
 
 	switch (qbetaf (a, b, &r, &e)) {
-	case 0: return ldexp (gnm_quad_value (&r), e);
+	case 0: return gnm_ldexp (gnm_quad_value (&r), e);
 	case 1: return gnm_pinf;
 	default: return gnm_nan;
 	}
@@ -948,17 +954,20 @@ qfactf (gnm_float x, GnmQuad *mant, int *exp2)
 	void *state;
 	gboolean res = 0;
 
-	if (gnm_isnan (x))
-		return 2;
+	*exp2 = 0;
 
-	if (x >= G_MAXINT / 2)
+	if (gnm_isnan (x) || (x < 0 && x == gnm_floor (x))) {
+		mant->h = mant->l = gnm_nan;
+		return 2;
+	}
+
+	if (x >= G_MAXINT / 2) {
+		mant->h = mant->l = gnm_pinf;
 		return 1;
+	}
 
 	if (x == gnm_floor (x)) {
-		/* Integer or infinite.  */
-		if (x < 0)
-			return 2;
-
+		/* 0, 1, 2, ...  */
 		if (!qfacti ((int)x, mant, exp2))
 			return 0;
 	}
@@ -1000,9 +1009,10 @@ qfactf (gnm_float x, GnmQuad *mant, int *exp2)
 		/* (y/e)^y */
 		gnm_quad_div (&f2, &y, &gnm_quad_e);
 		gnm_quad_pow (&f2, &ef2, &f2, &y);
-		if (ef2 > G_MAXINT || ef2 < G_MININT)
+		if (ef2 > G_MAXINT || ef2 < G_MININT) {
 			res = 1;
-		else
+			f2.h = f2.l = gnm_pinf;
+		} else
 			*exp2 += (int)ef2;
 		if (debug) g_printerr ("f2=%.20g\n", gnm_quad_value (&f2));
 
@@ -1042,6 +1052,7 @@ qfactf (gnm_float x, GnmQuad *mant, int *exp2)
 		}
 
 		if (qfacti ((int)w, &mFw, &eFw)) {
+			mant->h = mant->l = gnm_pinf;
 			res = 1;
 		} else {
 			GnmQuad r;
@@ -1066,9 +1077,11 @@ qgammaf (gnm_float x, GnmQuad *mant, int *exp2)
 {
 	if (x < -1.5 || x > 0.5)
 		return qfactf (x - 1, mant, exp2);
-	else if (gnm_isnan (x) || x == 0)
+	else if (gnm_isnan (x) || x == gnm_floor (x)) {
+		*exp2 = 0;
+		mant->h = mant->l = gnm_nan;
 		return 2;
-	else {
+	} else {
 		void *state = gnm_quad_start ();
 		GnmQuad qx;
 
@@ -1249,92 +1262,91 @@ static const guint32 lanczos_denom[G_N_ELEMENTS(lanczos_num)] = {
 	13339535, 2637558, 357423, 32670, 1925, 66, 1
 };
 
-void
-complex_gamma (gnm_complex *dst, gnm_complex const *src)
+/**
+ * gnm_complex_gamma:
+ * @z: a complex number
+ * @exp2: (out) (allow-none): Return location for power of 2.
+ *
+ * Returns: (transfer full): the Gamma function evaluated at @z.
+ */
+gnm_complex
+gnm_complex_gamma (gnm_complex z, int *exp2)
 {
-	if (gnm_complex_real_p (src)) {
-		gnm_complex_init (dst, gnm_gamma (src->re), 0);
-	} else if (src->re < 0) {
+	if (exp2)
+		*exp2 = 0;
+
+	if (GNM_CREALP (z)) {
+		return GNM_CREAL (exp2 ? gnm_gammax (z.re, exp2) : gnm_gamma (z.re));
+	} else if (z.re < 0) {
 		/* Gamma(z) = pi / (sin(pi*z) * Gamma(-z+1)) */
-		gnm_complex a, b, mz;
-
-		gnm_complex_init (&mz, -src->re, -src->im);
-		complex_fact (&a, &mz);
-
-		gnm_complex_init (&b,
-			      M_PIgnum * gnm_fmod (src->re, 2),
-			      M_PIgnum * src->im);
+		gnm_complex b = GNM_CMAKE (M_PIgnum * gnm_fmod (z.re, 2),
+					   M_PIgnum * z.im);
 		/* Hmm... sin overflows when b.im is large.  */
-		gnm_complex_sin (&b, &b);
-
-		gnm_complex_mul (&a, &a, &b);
-
-		gnm_complex_init (&b, M_PIgnum, 0);
-
-		gnm_complex_div (dst, &b, &a);
+		gnm_complex res = GNM_CDIV (GNM_CREAL (M_PIgnum),
+					    GNM_CMUL (gnm_complex_fact (GNM_CNEG (z), exp2),
+						      GNM_CSIN (b)));
+		if (exp2)
+			*exp2 = -*exp2;
+		return res;
 	} else {
-		gnm_complex zmh, zmhd2, zmhpg, f, f2, p, q, pq;
+		gnm_complex zmh, f, p, q;
 		int i;
 
 		i = G_N_ELEMENTS(lanczos_num) - 1;
-		gnm_complex_init (&p, lanczos_num[i], 0);
-		gnm_complex_init (&q, lanczos_denom[i], 0);
+		p = GNM_CREAL (lanczos_num[i]);
+		q = GNM_CREAL (lanczos_denom[i]);
 		while (--i >= 0) {
-			gnm_complex_mul (&p, &p, src);
+			p = GNM_CMUL (p, z);
 			p.re += lanczos_num[i];
-			gnm_complex_mul (&q, &q, src);
+			q = GNM_CMUL (q, z);
 			q.re += lanczos_denom[i];
 		}
-		gnm_complex_div (&pq, &p, &q);
 
-		gnm_complex_init (&zmh, src->re - 0.5, src->im);
-		gnm_complex_init (&zmhpg, zmh.re + lanczos_g, zmh.im);
-		gnm_complex_init (&zmhd2, zmh.re * 0.5, zmh.im * 0.5);
-		gnm_complex_pow (&f, &zmhpg, &zmhd2);
+		zmh = GNM_CMAKE (z.re - 0.5, z.im);
+		f = GNM_CPOW (GNM_CADD (zmh, GNM_CREAL (lanczos_g)),
+			      GNM_CSCALE (zmh, 0.5));
 
-		zmh.re = -zmh.re; zmh.im = -zmh.im;
-		gnm_complex_exp (&f2, &zmh);
-		gnm_complex_mul (&f2, &f, &f2);
-		gnm_complex_mul (&f2, &f2, &f);
-
-		gnm_complex_mul (dst, &f2, &pq);
+		return GNM_CMUL4 (f, GNM_CEXP (GNM_CNEG (zmh)), f, GNM_CDIV (p, q));
 	}
 }
 
 /* ------------------------------------------------------------------------- */
 
-void
-complex_fact (gnm_complex *dst, gnm_complex const *src)
+/**
+ * gnm_complex_fact:
+ * @z: a complex number
+ * @exp2: (out) (allow-none): Return location for power of 2.
+ *
+ * Returns: (transfer full): the factorial function evaluated at @z.
+ */
+gnm_complex
+gnm_complex_fact (gnm_complex z, int *exp2)
 {
-	if (gnm_complex_real_p (src)) {
-		gnm_complex_init (dst, gnm_fact (src->re), 0);
+	if (exp2)
+		*exp2 = 0;
+
+	if (GNM_CREALP (z)) {
+		return GNM_CREAL (exp2 ? gnm_factx (z.re, exp2) : gnm_fact (z.re));
 	} else {
-		/*
-		 * This formula is valid for all arguments except zero
-		 * which we conveniently handled above.
-		 */
-		gnm_complex gz;
-		complex_gamma (&gz, src);
-		gnm_complex_mul (dst, &gz, src);
+		// This formula is valid for all arguments except zero
+		// which we conveniently handled above.
+		return GNM_CMUL (gnm_complex_gamma (z, exp2), z);
 	}
 }
 
 /* ------------------------------------------------------------------------- */
 
 // D(a,z) := z^a * exp(-z) / Gamma (a + 1)
-static void
-complex_temme_D (gnm_complex *res, gnm_complex const *a, gnm_complex const *z)
+static gnm_complex 
+complex_temme_D (gnm_complex a, gnm_complex z)
 {
-	gnm_complex t, ez, fa;
+	gnm_complex t;
 
 	// The idea here is to control intermediate sizes and to avoid
 	// accuracy problems caused by exp and pow.  For now, do neither.
 
-	gnm_complex_pow (&t, z, a);
-	gnm_complex_exp (&ez, z);
-	gnm_complex_div (&t, &t, &ez);
-	complex_fact (&fa, a);
-	gnm_complex_div (res, &t, &fa);
+	t = GNM_CDIV (GNM_CPOW (z, a), GNM_CEXP (z));
+	return GNM_CDIV (t, gnm_complex_fact (a, NULL));
 }
 
 
@@ -1350,10 +1362,8 @@ gnm_complex_continued_fraction (gnm_complex *dst, size_t N,
 	size_t i;
 	const gboolean debug_cf = FALSE;
 
-	gnm_complex_init (&A0, 1, 0);
-	gnm_complex_init (&A1, 0, 0);
-	gnm_complex_init (&B0, 0, 0);
-	gnm_complex_init (&B1, 1, 0);
+	A0 = B1 = GNM_C1;
+	A1 = B0 = GNM_C0;
 
 	for (i = 1; i < N; i++) {
 		gnm_complex ai, bi, t1, t2, c1, c2, A2, B2;
@@ -1363,15 +1373,15 @@ gnm_complex_continued_fraction (gnm_complex *dst, size_t N,
 		cf (&ai, &bi, i, args);
 
 		/* Update A. */
-		gnm_complex_mul (&t1, &bi, &A1);
-		gnm_complex_mul (&t2, &ai, &A0);
-		gnm_complex_add (&A2, &t1, &t2);
+		t1 = GNM_CMUL (bi, A1);
+		t2 = GNM_CMUL (ai, A0);
+		A2 = GNM_CADD (t1, t2);
 		A0 = A1; A1 = A2;
 
 		/* Update B. */
-		gnm_complex_mul (&t1, &bi, &B1);
-		gnm_complex_mul (&t2, &ai, &B0);
-		gnm_complex_add (&B2, &t1, &t2);
+		t1 = GNM_CMUL (bi, B1);
+		t2 = GNM_CMUL (ai, B0);
+		B2 = GNM_CADD (t1, t2);
 		B0 = B1; B1 = B2;
 
 		/* Rescale */
@@ -1383,25 +1393,25 @@ gnm_complex_continued_fraction (gnm_complex *dst, size_t N,
 			if (m == 0)
 				return FALSE;
 
-			(void)frexp (m, &e);
+			(void)gnm_frexp (m, &e);
 			if (debug_cf)
 				g_printerr ("rescale by 2^%d\n", -e);
 
-			s = ldexp (1, -e);
-			A0.re *= s; A0.im *= s;
-			A1.re *= s; A1.im *= s;
-			B0.re *= s; B0.im *= s;
-			B1.re *= s; B1.im *= s;
+			s = gnm_ldexp (1, -e);
+			A0 = GNM_CSCALE (A0, s);
+			A1 = GNM_CSCALE (A1, s);
+			B0 = GNM_CSCALE (B0, s);
+			B1 = GNM_CSCALE (B1, s);
 		}
 
 		/* Check for convergence */
-		gnm_complex_mul (&t1, &A1, &B0);
-		gnm_complex_mul (&t2, &A0, &B1);
-		gnm_complex_sub (&c1, &t1, &t2);
+		t1 = GNM_CMUL (A1, B0);
+		t2 = GNM_CMUL (A0, B1);
+		c1 = GNM_CSUB (t1, t2);
 
-		gnm_complex_mul (&c2, &B0, &B1);
+		c2 = GNM_CMUL (B0, B1);
 
-		gnm_complex_div (&t1, &A1, &B1);
+		t1 = GNM_CDIV (A1, B1);
 		if (debug_cf) {
 			g_printerr ("  a : %.20g + %.20g I\n", ai.re, ai.im);
 			g_printerr ("  b : %.20g + %.20g I\n", bi.re, bi.im);
@@ -1410,18 +1420,18 @@ gnm_complex_continued_fraction (gnm_complex *dst, size_t N,
 			g_printerr ("%3zd : %.20g + %.20g I\n", i, t1.re, t1.im);
 		}
 
-		if (gnm_complex_mod (&c1) <= gnm_complex_mod (&c2) * (GNM_EPSILON /2))
+		if (GNM_CABS (c1) <= GNM_CABS (c2) * (GNM_EPSILON /2))
 			break;
 	}
 
 	if (i == N) {
 		g_printerr ("continued fraction failed to converge.\n");
-		/* Make the failure obvious. */
-		dst->re = dst->im = gnm_nan;
+		// Make the failure obvious.
+		*dst = GNM_CNAN;
 		return FALSE;
 	}
 
-	gnm_complex_div (dst, &A1, &B1);
+	*dst = GNM_CDIV (A1, B1);
 	return TRUE;
 }
 
@@ -1433,36 +1443,28 @@ igamma_lower_coefs (gnm_complex *ai, gnm_complex *bi, size_t i,
 	gnm_complex const *z = args + 1;
 
 	if (i == 1)
-		gnm_complex_real (ai, 1);
+		*ai = GNM_C1;
 	else if (i & 1) {
-		gnm_complex f;
-		gnm_complex_real (&f, i >> 1);
-		gnm_complex_mul (ai, &f, z);
+		*ai = GNM_CSCALE (*z, i >> 1);
 	} else {
-		gnm_complex f;
-		gnm_complex_init (&f, -(a->re + ((i >> 1) - 1)), -a->im);
-		gnm_complex_mul (ai, &f, z);
+		gnm_complex f = GNM_CMAKE (-(a->re + ((i >> 1) - 1)), -a->im);
+		*ai = GNM_CMUL (f, *z);
 	}
 
-	gnm_complex_init (bi, a->re + (i - 1), a->im);
+	*bi = GNM_CMAKE (a->re + (i - 1), a->im);
 }
 
 static gboolean
 igamma_lower_cf (gnm_complex *dst, const gnm_complex *a, const gnm_complex *z)
 {
 	gnm_complex args[2] = { *a, *z };
-	gnm_complex f, mz, res;
+	gnm_complex res;
 
 	if (!gnm_complex_continued_fraction (&res, 100, igamma_lower_coefs, args))
 		return FALSE;
 
 	// FIXME: The following should be handled without creating big numbers.
-
-       	mz.re = -z->re, mz.im = -z->im;
-	gnm_complex_exp (&f, &mz);
-	gnm_complex_mul (&res, &res, &f);
-	gnm_complex_pow (&f, z, a);
-	gnm_complex_mul (dst, &res, &f);
+	*dst = GNM_CMUL3 (res, GNM_CEXP (GNM_CNEG (*z)), GNM_CPOW (*z, *a));
 
 	return TRUE;
 }
@@ -1470,10 +1472,10 @@ igamma_lower_cf (gnm_complex *dst, const gnm_complex *a, const gnm_complex *z)
 static gboolean
 igamma_upper_asymp (gnm_complex *dst, const gnm_complex *a, const gnm_complex *z)
 {
-	gnm_float am = gnm_complex_mod (a);
-	gnm_float zm = gnm_complex_mod (z);
+	gnm_float am = GNM_CABS (*a);
+	gnm_float zm = GNM_CABS (*z);
 	gnm_float n0;
-	gnm_complex s, t, am1;
+	gnm_complex s, t;
 	gboolean debug = FALSE;
 	size_t i;
 
@@ -1491,31 +1493,27 @@ igamma_upper_asymp (gnm_complex *dst, const gnm_complex *a, const gnm_complex *z
 	if (2 * zm < GNM_MANT_DIG * M_LN2gnum)
 		return FALSE;
 
-	gnm_complex_real (&s, 0);
+	s = GNM_C0;
 
-	gnm_complex_init (&am1, a->re - 1, a->im);
-	complex_temme_D (&t, &am1, z);
+	t = complex_temme_D (GNM_CSUB (*a, GNM_C1), *z);
 
 	for (i = 0; i < 100; i++) {
-		gnm_complex api;
-
-		gnm_complex_add (&s, &s, &t);
+		s = GNM_CADD (s, t);
 
 		if (debug) {
 			g_printerr ("%3zd: t=%.20g + %.20g * I\n", i, t.re, t.im);
 			g_printerr ("   : s=%.20g + %.20g * I\n", s.re, s.im);
 		}
 
-		if (gnm_complex_mod (&t) <= gnm_complex_mod (&s) * GNM_EPSILON) {
+		if (GNM_CABS (t) <= GNM_CABS (s) * GNM_EPSILON) {
 			if (debug)
 				g_printerr ("igamma_upper_asymp converged.\n");
 			*dst = s;
 			return TRUE;
 		}
 
-		gnm_complex_div (&t, &t, z);
-		gnm_complex_init (&api, a->re - (i + 1), a->im);
-		gnm_complex_mul (&t, &t, &api);
+		t = GNM_CDIV (t, *z);
+		t = GNM_CMUL (t, GNM_CSUB (*a, GNM_CREAL (i + 1)));
 	}
 
 	if (debug)
@@ -1525,100 +1523,103 @@ igamma_upper_asymp (gnm_complex *dst, const gnm_complex *a, const gnm_complex *z
 }
 
 static void
-fixup_upper_real (gnm_complex *res, gnm_complex const *a, gnm_complex const *z)
+fixup_upper_real (gnm_complex *res, gnm_complex a, gnm_complex z)
 {
 	// This assumes we have an upper gamma regularized result.
 	//
 	// It appears that upper algorithms have trouble with negative real z
 	// (for example, such z being outside the allowed domain) in some cases.
-	
 
-	if (gnm_complex_real_p (z) && z->re < 0 &&
-	    gnm_complex_real_p (a) && a->re != gnm_floor (a->re)) {
+	if (GNM_CREALP (z) && z.re < 0 &&
+	    GNM_CREALP (a) && a.re != gnm_floor (a.re)) {
 		// Everything in the lower power series is real expect z^a
 		// which is not.  So...
 		// 1. Flip to lower gamma
 		// 2. Assume modulus is correct
 		// 3. Use exact angle for lower gamma
 		// 4. Flip back to upper gamma
-		gnm_complex lres = *res;
-		lres.re = 1 - lres.re;
-
-		gnm_complex_from_polar_pi (res,
-					   gnm_complex_mod (&lres),
-					   a->re);
-		res->re = 1 - res->re;
-		res->im = 0 - res->im;
+		gnm_complex lres = GNM_CSUB (GNM_C1, *res);
+		*res = GNM_CPOLARPI (GNM_CABS (lres), a.re);
+		*res = GNM_CSUB (GNM_C1, *res);
 	}
 }
 
-void
-complex_igamma (gnm_complex *dst, const gnm_complex *a, const gnm_complex *z,
-		gboolean lower, gboolean regularized)
+/**
+ * gnm_complex_igamma:
+ * @a: a complex number
+ * @z: a complex number
+ * @lower: determines if upper or lower incomplete gamma is desired.
+ * @regularized: determines if the result should be normalized by Gamma(@a).
+ *
+ * Returns: (transfer full): the incomplete gamma function evaluated at
+ * @a and @z.
+ */
+gnm_complex
+gnm_complex_igamma (gnm_complex a, gnm_complex z,
+		    gboolean lower, gboolean regularized)
 {
 	gnm_complex res, ga;
 	gboolean have_lower, have_regularized;
 	gboolean have_ga = FALSE;
 
-	if (regularized && gnm_complex_real_p (a) &&
-	    a->re <= 0 && a->re == gnm_floor (a->re)) {
-		gnm_complex_real (&res, 0);
+	if (regularized && GNM_CREALP (a) &&
+	    a.re <= 0 && a.re == gnm_floor (a.re)) {
+		res = GNM_C0;
 		have_lower = FALSE;
 		have_regularized = TRUE;
 		goto fixup;
 	}
 
-	if (gnm_complex_real_p (a) && a->re >= 0 &&
-	    gnm_complex_real_p (z) && z->re >= 0) {
-		gnm_complex_init (&res, pgamma (z->re, a->re, 1, lower, FALSE), 0);
+	if (GNM_CREALP (a) && a.re >= 0 &&
+	    GNM_CREALP (z) && z.re >= 0) {
+		res = GNM_CREAL (pgamma (z.re, a.re, 1, lower, FALSE));
 		have_lower = lower;
 		have_regularized = TRUE;
 		goto fixup;
 	}
 
-	if (igamma_upper_asymp (&res, a, z)) {
+	if (igamma_upper_asymp (&res, &a, &z)) {
 		have_lower = FALSE;
 		have_regularized = TRUE;
 		fixup_upper_real (&res, a, z);
 		goto fixup;
 	}
 
-	if (igamma_lower_cf (&res, a, z)) {
+	if (igamma_lower_cf (&res, &a, &z)) {
 		have_lower = TRUE;
 		have_regularized = FALSE;
 		goto fixup;
 	}
 
-	gnm_complex_init (dst, gnm_nan, gnm_nan);
-	return;
+	// Failure of all sub-methods.
+	return GNM_CNAN;
 
 fixup:
 	// Fixup to the desired form as needed.  This is not ideal.
 	// 1. Regularizing here is too late due to overflow.
 	// 2. Upper/lower switch can have cancellation
 	if (regularized != have_regularized) {
-		complex_gamma (&ga, a);
+		ga = gnm_complex_gamma (a, NULL);
 		have_ga = TRUE;
 
 		if (have_regularized)
-			gnm_complex_mul (&res, &res, &ga);
+			res = GNM_CMUL (res, ga);
 		else
-			gnm_complex_div (&res, &res, &ga);
+			res = GNM_CDIV (res, ga);
 		have_regularized = TRUE;
 	}
 
 	if (lower != have_lower) {
 		if (have_regularized) {
-			res.re = 1 - res.re;
-			res.im = 0 - res.im;
+			res = GNM_CSUB (GNM_C1, res);
 		} else {
 			if (!have_ga)
-				complex_gamma (&ga, a);
-			gnm_complex_sub (&res, &ga, &res);
+				ga = gnm_complex_gamma (a, NULL);
+			res = GNM_CSUB (ga, res);
 		}
 	}
 
-	*dst = res;
+	return res;
 }
 
 /* ------------------------------------------------------------------------- */
