@@ -850,7 +850,7 @@ vector_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *unknown)
 {
 	GuppiReadState *state = (GuppiReadState *) xin->user_state;
 	GOData *data;
-	if (state->cur_index > 255)
+	if (state->cur_index >= state->max_data)
 		return;
 	data = g_object_new (GNM_GO_DATA_VECTOR_TYPE, NULL);
 	go_data_unserialize (data, xin->content->str, (void*) state->convs);
@@ -954,7 +954,7 @@ dim_start (GsfXMLIn *xin, xmlChar const **attrs)
 		else if (0 == strcmp (attrs[i], "ID"))
 			id = strtoul (attrs[i+1], NULL, 10);
 	if (!desc ||
-	    id > state->data->len || g_ptr_array_index (state->data, id) == NULL)
+	    id >= state->data->len || g_ptr_array_index (state->data, id) == NULL)
 		return;
 	if (0 == strcmp (name, "values"))
 		type = GOG_MS_DIM_VALUES;
