@@ -220,15 +220,6 @@ gnm_soi_new_view (SheetObject *so, SheetObjectViewContainer *container)
 	return gnm_pane_object_register (so, item, TRUE);
 }
 
-static GOImageFormat const standard_formats[] = {
-	GO_IMAGE_FORMAT_PNG,
-	GO_IMAGE_FORMAT_JPG,
-	GO_IMAGE_FORMAT_SVG,
-	GO_IMAGE_FORMAT_EMF,
-	GO_IMAGE_FORMAT_WMF,
-	GO_IMAGE_FORMAT_EPS
-};
-
 static GtkTargetList *
 gnm_soi_get_target_list (SheetObject const *so)
 {
@@ -353,6 +344,7 @@ content_start (GsfXMLIn *xin, xmlChar const **attrs)
 	else if (attr_eq (attrs[0], "name"))
 			image_name = CXML2C (attrs[1]);
 
+	g_free (soi->type);
 	soi->type = g_strdup (image_type);
 	if (image_name)
 		soi->name = g_strdup (image_name);
@@ -494,8 +486,8 @@ gnm_soi_assign_to_sheet (SheetObject *so, Sheet *sheet)
 
 	if (soi->image/* && !go_image_get_name (soi->image)*/) {
 		GODoc *doc = GO_DOC (sheet->workbook);
-		GOImage *image = go_doc_add_image 
-			(doc, 
+		GOImage *image = go_doc_add_image
+			(doc,
 			 (soi->name != NULL) ? soi->name : go_image_get_name (soi->image),
 			 soi->image);
 		if (soi->image != image) {
