@@ -452,7 +452,7 @@ value_new_array_empty (guint cols, guint rows)
 	for (x = 0; x < cols; x++) {
 		v->vals[x] = g_new (GnmValue *, rows);
 		for (y = 0; y < rows; y++)
-			v->vals[x][y] = NULL;
+			v->vals[x][y] = value_new_empty ();
 	}
 	return (GnmValue *)v;
 }
@@ -1360,7 +1360,9 @@ value_compare_real (GnmValue const *a, GnmValue const *b,
 
 	switch (PAIR (ta,tb)) {
 	case CPAIR (VALUE_EMPTY,VALUE_EMPTY):
-		g_assert_not_reached(); /* Should have hit trivial case.  */
+		/* In most cases this is handled by the trivial case. */
+		/* We can get here if one of a and b is NULL and the  */
+		/* is not but contains an empty value.                */
 		return IS_EQUAL;
 
 	/* ---------------------------------------- */
@@ -1674,6 +1676,11 @@ find_column_of_field (GnmEvalPos const *ep,
 	int   begin_col, end_col, row, n, column;
 	int   offset;
 
+	// I'm not certain we shoul demand this, but the code clearly wants
+	// it.
+	if (!VALUE_IS_CELLRANGE (database))
+		return -1;
+
 	offset = database->v_range.cell.a.col;
 
 	if (VALUE_IS_FLOAT (field))
