@@ -202,12 +202,19 @@ xml_write_sheet_names (GnmOutputXML *state)
 	for (i = 0 ; i < n ; i++) {
 		sheet = workbook_sheet_by_index (state->wb, i);
 		gsf_xml_out_start_element (state->output, GNM "SheetName");
+
+		/*
+		 * Note, that we explicitly namespace these attributes.
+		 * That is not wrong, per se, but note that Gnumeric until
+		 * 1.12.22 will not read files without this explicit name-
+		 * space and that the abbreviation must be "gnm".
+		 */
 		if (sheet->sheet_type == GNM_SHEET_OBJECT)
 			gsf_xml_out_add_cstr (state->output, GNM "SheetType", "object");
 		gsf_xml_out_add_int (state->output, GNM "Cols",
-							 gnm_sheet_get_max_cols (sheet));
+				     gnm_sheet_get_max_cols (sheet));
 		gsf_xml_out_add_int (state->output, GNM "Rows",
-							 gnm_sheet_get_max_rows (sheet));
+				     gnm_sheet_get_max_rows (sheet));
 		gsf_xml_out_add_cstr (state->output, NULL, sheet->name_unquoted);
 		gsf_xml_out_end_element (state->output); /* </gnm:SheetName> */
 	}
@@ -363,11 +370,11 @@ xml_write_print_info (GnmOutputXML *state, GnmPrintInformation *pi)
 	gsf_xml_out_start_element (state->output, GNM "Scale");
 	if (pi->scaling.type == PRINT_SCALE_PERCENTAGE) {
 		gsf_xml_out_add_cstr_unchecked  (state->output, "type", "percentage");
-		gsf_xml_out_add_float  (state->output, "percentage", pi->scaling.percentage.x, -1);
+		go_xml_out_add_double  (state->output, "percentage", pi->scaling.percentage.x);
 	} else {
 		gsf_xml_out_add_cstr_unchecked  (state->output, "type", "size_fit");
-		gsf_xml_out_add_float  (state->output, "cols", pi->scaling.dim.cols, -1);
-		gsf_xml_out_add_float  (state->output, "rows", pi->scaling.dim.rows, -1);
+		go_xml_out_add_double  (state->output, "cols", pi->scaling.dim.cols);
+		go_xml_out_add_double  (state->output, "rows", pi->scaling.dim.rows);
 	}
 	gsf_xml_out_end_element (state->output);
 
@@ -998,7 +1005,7 @@ xml_write_filter_field (GnmOutputXML *state,
 			cond->op[0] & 1 ? TRUE : FALSE);
 		gsf_xml_out_add_bool (state->output, "items",
 			cond->op[0] & 2 ? TRUE : FALSE);
-		gsf_xml_out_add_float (state->output, "count", cond->count, 4);
+		go_xml_out_add_double (state->output, "count", cond->count);
 		break;
 	}
 
@@ -1080,6 +1087,8 @@ xml_write_solver (GnmOutputXML *state)
 		param->options.automatic_scaling);
 	gsf_xml_out_add_bool (state->output, "ProgramR",
 		param->options.program_report);
+	gsf_xml_out_add_bool (state->output, "SensitivityR",
+		param->options.sensitivity_report);
 
 	for (ptr = param->constraints; ptr != NULL ; ptr = ptr->next) {
 		GnmSolverConstraint const *c = ptr->data;
@@ -1241,6 +1250,20 @@ xml_write_objects (GnmOutputXML *state, GSList *objects)
 	for (ptr = objects ;ptr != NULL ; ptr = ptr->next) {
 		SheetObject *so = ptr->data;
 		SheetObjectClass *klass = GNM_SO_CLASS (G_OBJECT_GET_CLASS (so));
+		GnmRange cell_bound = so->anchor.cell_bound;
+
+		switch (so->anchor.mode) {
+		case GNM_SO_ANCHOR_TWO_CELLS:
+			break;
+		case GNM_SO_ANCHOR_ONE_CELL:
+			cell_bound.end = cell_bound.start;
+			break;
+		case GNM_SO_ANCHOR_ABSOLUTE:
+			range_init (&cell_bound, 0, 0, 0, 0);
+			break;
+		default:
+			g_assert_not_reached ();
+		}
 
 		if (needs_container) {
 			needs_container = FALSE;
@@ -1256,7 +1279,13 @@ xml_write_objects (GnmOutputXML *state, GSList *objects)
 		gsf_xml_out_start_element (state->output, tmp);
 		if (so->name)
 			gsf_xml_out_add_cstr (state->output, "Name", so->name);
-		gsf_xml_out_add_cstr (state->output, "ObjectBound", range_as_string (&so->anchor.cell_bound));
+		if (so->anchor.mode != GNM_SO_ANCHOR_ABSOLUTE)
+			gsf_xml_out_add_cstr (state->output, "ObjectBound", range_as_string (&cell_bound));
+		if (so->anchor.mode != GNM_SO_ANCHOR_TWO_CELLS)
+			gsf_xml_out_add_enum (state->output,
+					      "AnchorMode",
+					      GNM_SHEET_OBJECT_ANCHOR_MODE_TYPE,
+					      so->anchor.mode);
 		snprintf (buffer, sizeof (buffer), "%.3g %.3g %.3g %.3g",
 			  so->anchor.offset [0], so->anchor.offset [1],
 			  so->anchor.offset [2], so->anchor.offset [3]);
@@ -1406,8 +1435,8 @@ xml_write_calculation (GnmOutputXML *state)
 		"EnableIteration",	state->wb->iteration.enabled);
 	gsf_xml_out_add_int (state->output,
 		"MaxIterations",	state->wb->iteration.max_number);
-	gsf_xml_out_add_float (state->output,
-		"IterationTolerance",	state->wb->iteration.tolerance, -1);
+	go_xml_out_add_double (state->output,
+		"IterationTolerance",	state->wb->iteration.tolerance);
 	xml_write_date_conventions_as_attr (state,
 					    workbook_date_conv (state->wb));
 	xml_write_number_system (state);
